// Copyright 2023 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

syntax = "proto3";

package google.ads.googleads.v14.resources;

import "google/ads/googleads/v14/common/customizer_value.proto";
import "google/ads/googleads/v14/enums/customizer_value_status.proto";
import "google/api/field_behavior.proto";
import "google/api/resource.proto";

option csharp_namespace = "Google.Ads.GoogleAds.V14.Resources";
option go_package = "google.golang.org/genproto/googleapis/ads/googleads/v14/resources;resources";
option java_multiple_files = true;
option java_outer_classname = "AdGroupCustomizerProto";
option java_package = "com.google.ads.googleads.v14.resources";
option objc_class_prefix = "GAA";
option php_namespace = "Google\\Ads\\GoogleAds\\V14\\Resources";
option ruby_package = "Google::Ads::GoogleAds::V14::Resources";

// A customizer value for the associated CustomizerAttribute at the AdGroup
// level.
message AdGroupCustomizer {
  option (google.api.resource) = {
    type: "googleads.googleapis.com/AdGroupCustomizer"
    pattern: "customers/{customer_id}/adGroupCustomizers/{ad_group_id}~{customizer_attribute_id}"
  };

  // Immutable. The resource name of the ad group customizer.
  // Ad group customizer resource names have the form:
  //
  // `customers/{customer_id}/adGroupCustomizers/{ad_group_id}~{customizer_attribute_id}`
  string resource_name = 1 [
    (google.api.field_behavior) = IMMUTABLE,
    (google.api.resource_reference) = {
      type: "googleads.googleapis.com/AdGroupCustomizer"
    }
  ];

  // Immutable. The ad group to which the customizer attribute is linked.
  string ad_group = 2 [
    (google.api.field_behavior) = IMMUTABLE,
    (google.api.resource_reference) = {
      type: "googleads.googleapis.com/AdGroup"
    }
  ];

  // Required. Immutable. The customizer attribute which is linked to the ad
  // group.
  string customizer_attribute = 3 [
    (google.api.field_behavior) = REQUIRED,
    (google.api.field_behavior) = IMMUTABLE,
    (google.api.resource_reference) = {
      type: "googleads.googleapis.com/CustomizerAttribute"
    }
  ];

  // Output only. The status of the ad group customizer.
  google.ads.googleads.v14.enums.CustomizerValueStatusEnum.CustomizerValueStatus
      status = 4 [(google.api.field_behavior) = OUTPUT_ONLY];

  // Required. The value to associate with the customizer attribute at this
  // level. The value must be of the type specified for the CustomizerAttribute.
  google.ads.googleads.v14.common.CustomizerValue value = 5
      [(google.api.field_behavior) = REQUIRED];
}
